#!/bin/bash

set -e
set -u

source ./installer/sudo-cmd.sh
source ./installer/http-get.sh

### IMPORTANT ###
###  VERSION  ###
#my_app_ver="v1.1"
my_app_ver="installer-v2"
export NODE_VERSION="v8.9.0"
#################



my_app_name=goldilocks
my_app_pkg_name=com.daplie.goldilocks.web
my_app_dir=$(mktemp -d)
my_app_dist=$my_app_dir/opt/goldilocks/lib/node_modules/goldilocks/dist
git_base="https://git.daplie.com/Daplie/goldilocks.js.git"
installer_base="https://git.daplie.com/Daplie/goldilocks.js/raw/$my_app_ver"



#
# Install to tmp location, then move to /opt
#
echo "Installing to $my_app_dir (will be moved after install)"
mkdir -p $my_app_dir/opt/goldilocks/lib/node_modules/goldilocks
git clone $git_base $my_app_dir/opt/goldilocks/lib/node_modules/goldilocks
pushd $my_app_dir/opt/goldilocks/lib/node_modules/goldilocks
  git checkout $my_app_ver
popd
mkdir -p "$my_app_dir/opt/$my_app_name"/{lib,bin,etc}
ln -s ../lib/node_modules/$my_app_name/bin/$my_app_name.js $my_app_dir/opt/$my_app_name/bin/goldilocks
ln -s ../lib/node_modules/$my_app_name/bin/$my_app_name.js $my_app_dir/opt/$my_app_name/bin/goldilocks.js
mkdir -p "$my_app_dir/etc/$my_app_name"
chmod 775 "$my_app_dir/etc/$my_app_name"
cat "$my_app_dist/etc/$my_app_name/$my_app_name.example.yml" > "$my_app_dir/etc/$my_app_name/$my_app_name.example.yml"
chmod 664 "$my_app_dir/etc/$my_app_name/$my_app_name.example.yml"
mkdir -p $my_app_dir/srv/www
mkdir -p $my_app_dir/var/www
mkdir -p $my_app_dir/var/log/$my_app_name



#
# Dependencies
#
echo $NODE_VERSION > /tmp/NODEJS_VER
export NODE_PATH=$my_app_dir/opt/goldilocks/lib/node_modules
export PATH=$PATH:$my_app_dir/opt/goldilocks/bin/
export NPM_CONFIG_PREFIX=$my_app_dir/opt/goldilocks
http_bash "https://git.coolaj86.com/coolaj86/node-installer.sh/raw/v1.1/install.sh"
my_npm="$NPM_CONFIG_PREFIX/bin/npm"
$my_npm install -g npm@4
pushd $my_app_dir/opt/goldilocks/lib/node_modules/goldilocks
  $my_npm install
popd
pushd $my_app_dir/opt/goldilocks/lib/node_modules/goldilocks/packages/assets
  OAUTH3_GIT_URL="https://git.daplie.com/Oauth3/oauth3.js.git"
  git clone ${OAUTH3_GIT_URL} oauth3.org || true
  ln -s oauth3.org org.oauth3
  pushd oauth3.org
    git remote set-url origin ${OAUTH3_GIT_URL}
    git checkout v1.2
    git pull
  popd

  mkdir -p jquery.com
  ln -s jquery.com com.jquery
  pushd jquery.com
    http_get 'https://code.jquery.com/jquery-3.1.1.js' jquery-3.1.1.js
  popd

  mkdir -p google.com
  ln -s google.com com.google
  pushd google.com
    http_get 'https://ajax.googleapis.com/ajax/libs/angularjs/1.6.2/angular.min.js' angular.1.6.2.min.js
  popd

  mkdir -p well-known
  ln -s well-known .well-known
  pushd well-known
    ln -snf ../oauth3.org/well-known/oauth3 ./oauth3
  popd
  echo "installed dependencies"
popd



#
# System Service
#
source ./installer/my-root.sh
echo "Pre-installation to $my_app_dir complete, now installing to $my_root/ ..."
if [ type -p tree ]; then
  #tree -I "node_modules|include|share" $my_app_dir
  tree -L 6 -I "include|share|npm" $my_app_dir
else
  ls $my_app_dir
fi

source ./installer/my-user-my-group.sh
echo "User $my_user Group $my_group"

$sudo_cmd chown -R $my_user:$my_group $my_app_dir
rsync -a $my_app_dir/ $my_root/
rsync -a --ignore-existing $my_app_dist/etc/goldilocks/goldilocks.yml $my_root/etc/goldilocks/goldilocks.yml
source ./installer/install-system-service.sh

# Change to admin perms
$sudo_cmd chown -R $my_user:$my_group $my_root/opt/$my_app_name
$sudo_cmd chown -R $my_user:$my_group $my_root/var/www $my_root/srv/www

# make sure the files are all read/write for the owner and group, and then set
# the setuid and setgid bits so that any files/directories created inside these
# directories have the same owner and group.
$sudo_cmd chmod -R ug+rwX /opt/$my_app_name
find /opt/$my_app_name -type d -exec $sudo_cmd chmod ug+s {} \;


rm -rf $my_app_dir
